As agreed (I hope I'm not wrong) on the LMML use "remote-endpoint"
property instead of "remote". Also add kerneldoc description for
the function.

Signed-off-by: Sylwester Nawrocki <s.nawro...@samsung.com>
Signed-off-by: Kyungmin Park <kyungmin.p...@samsung.com>
---
 drivers/media/v4l2-core/v4l2-of.c |   12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

diff --git a/drivers/media/v4l2-core/v4l2-of.c 
b/drivers/media/v4l2-core/v4l2-of.c
index 032ee67..10a06e4 100644
--- a/drivers/media/v4l2-core/v4l2-of.c
+++ b/drivers/media/v4l2-core/v4l2-of.c
@@ -186,13 +186,19 @@ struct device_node *v4l2_of_get_next_link(const struct 
device_node *parent,
 }
 EXPORT_SYMBOL(v4l2_of_get_next_link);
 
-/* Return a refcounted DT node, owning the link, referenced by "remote" */
+/**
+ * v4l2_of_get_remote() - get device node corresponding to remote enpoint
+ * @node: local endpoint node
+ *
+ * Return: Remote device node associated with remote endpoint node linked
+ *        to @node. Use of_node_put() on it when done.
+ */
 struct device_node *v4l2_of_get_remote(const struct device_node *node)
 {
        struct device_node *remote, *tmp;
 
-       /* Get remote link DT node */
-       remote = of_parse_phandle(node, "remote", 0);
+       /* Get remote endpoint DT node */
+       remote = of_parse_phandle(node, "remote-endpoint", 0);
        if (!remote)
                return NULL;
 
-- 
1.7.9.5

--
To unsubscribe from this list: send the line "unsubscribe linux-media" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to